@@ -25,10 +25,25 @@ module DiasporaFederation
       #   @return [Boolean] if the author is sharing with the person
       property :sharing, :boolean, default: true
 
+      # @!attribute [r] blocking
+      #   @return [Boolean] if the author is blocking the person
+      property :blocking, :boolean, optional: true, default: false
+
       # @return [String] string representation of this object
       def to_s
         "Contact:#{author}:#{recipient}"
       end
+
+      private
+
+      def validate
+        super
+
+        return unless (following || sharing) && blocking
+
+        raise ValidationError,
+              "flags invalid: following:#{following}/sharing:#{sharing} and blocking:#{blocking} can't both be true"
+      end
     end
   end
 end
