@@ -8,12 +8,12 @@ module DiasporaFederation
       #   A random string of at least 16 chars
       #   @see Validation::Rule::Guid
       #   @return [String] poll guid
-      property :guid
+      property :guid, :string
 
       # @!attribute [r] question
       #   Text of the question posed by a user
       #   @return [String] question
-      property :question
+      property :question, :string
 
       # @!attribute [r] poll_answers
       #   Array of possible answers for the poll
