@@ -4,10 +4,6 @@ module DiasporaFederation
     #
     # @see Validators::PollParticipationValidator
     class PollParticipation < Entity
-      # Old signature order
-      # @deprecated
-      LEGACY_SIGNATURE_ORDER = %i(guid parent_guid author poll_answer_guid).freeze
-
       # The {PollParticipation} parent is a {Poll}
       PARENT_TYPE = "Poll".freeze
 
@@ -17,7 +13,7 @@ module DiasporaFederation
       #   Guid of the answer selected by the user
       #   @see PollAnswer#guid
       #   @return [String] poll answer guid
-      property :poll_answer_guid
+      property :poll_answer_guid, :string
     end
   end
 end
