@@ -1,12 +1,14 @@
 module DiasporaFederation
   module Validators
     # This validates a {Entities::AccountMigration}.
-    class AccountMigrationValidator < Validation::Validator
+    class AccountMigrationValidator < OptionalAwareValidator
       include Validation
 
-      rule :author, %i[not_empty diaspora_id]
+      rule :author, :diaspora_id
 
       rule :profile, :not_nil
+
+      rule :old_identity, :diaspora_id
     end
   end
 end
