@@ -1,13 +1,14 @@
 module DiasporaFederation
   module Validators
     # This validates a {Entities::Contact}.
-    class ContactValidator < Validation::Validator
+    class ContactValidator < OptionalAwareValidator
       include Validation
 
-      rule :author, %i[not_empty diaspora_id]
-      rule :recipient, %i[not_empty diaspora_id]
+      rule :author, :diaspora_id
+      rule :recipient, :diaspora_id
       rule :following, :boolean
       rule :sharing, :boolean
+      rule :blocking, :boolean
     end
   end
 end
