@@ -1,12 +1,12 @@
 module DiasporaFederation
   module Validators
     # This validates a {Entities::Person}.
-    class PersonValidator < Validation::Validator
+    class PersonValidator < OptionalAwareValidator
       include Validation
 
       rule :guid, :guid
 
-      rule :author, %i[not_empty diaspora_id]
+      rule :author, :diaspora_id
 
       rule :url, %i[not_nil URI]
 
