@@ -1,13 +1,14 @@
 module DiasporaFederation
   module Validators
     # This validates a {Entities::Profile}.
-    class ProfileValidator < Validation::Validator
+    class ProfileValidator < OptionalAwareValidator
       include Validation
 
       rule :author, :diaspora_id
 
       # The name must not contain a semicolon because of mentions.
       # @{<full_name> ; <diaspora_id>}
+      rule :full_name, regular_expression: {regex: /\A[^;]{,70}\z/}
       rule :first_name, regular_expression: {regex: /\A[^;]{,32}\z/}
       rule :last_name, regular_expression: {regex: /\A[^;]{,32}\z/}
 
